#ifndef BPSMMedia_h
#define BPSMMedia_h

#import <Foundation/Foundation.h>
#import "BPSMLiveStream.h"

//! Represents single video content. It can be in multiple formats and qualities.
@interface BPSMMedia : NSObject

//! Media asset id.
@property NSString *id;

//! Media asset title.
@property NSString *title;

//! Media duration in seconds.
@property NSNumber *duration;

//! Array of BPSMMediaSource objects.
@property NSMutableArray *source;

//! Array of BPSMSplashImage objects.
@property NSMutableArray *splashImages;

//! Url pointing to media landing page.
@property NSString *mediaLandingPage;

//! Subtitles configuration for subtitles not embedded in video stream
//! (loading one language from single external file).
//! Array of BPSMSubtitlesFile objects.
@property NSMutableArray *subtitlesSets;

//! Configuration holder for live stream transmission.
@property BPSMLiveStream *liveStream;

+ (BPSMMedia *) newWithMediaSource: (NSString *)mediaSourceUrl;
+ (BPSMMedia *) newWithMediaSource: (NSString *)mediaSourceUrl
                   withSplashImage:(NSString *)splashImageUrl;
+ (BPSMMedia *) newFromNSDictionary: (NSDictionary *)dict;

- (NSDictionary *) toNSDictionary;

@end

#endif /* BPSMMedia_h */
